==> jc-1.4.0.tar.gz: polyglot/main/Report.h <==
// public class polyglot.main.Report

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf9f146bdb7bc44d polyglot_main_Report

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_main_Report_H_
#define _JC_polyglot_main_Report_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Stack$object;

// Typedefs
typedef struct _jc_polyglot_main_Report$sub_refs	_jc_polyglot_main_Report$sub_refs;
typedef struct _jc_polyglot_main_Report$sub_nonrefs	_jc_polyglot_main_Report$sub_nonrefs;
typedef struct _jc_polyglot_main_Report$refs	_jc_polyglot_main_Report$refs;
typedef struct _jc_polyglot_main_Report$nonrefs	_jc_polyglot_main_Report$nonrefs;
typedef struct _jc_polyglot_main_Report$object	_jc_polyglot_main_Report$object;

typedef struct _jc_polyglot_main_Report$fields_struct	_jc_polyglot_main_Report$fields_struct;
typedef const struct _jc_polyglot_main_Report$vmethods	_jc_polyglot_main_Report$vmethods;
typedef const struct _jc_polyglot_main_Report$vtable	_jc_polyglot_main_Report$vtable;
typedef const struct _jc_polyglot_main_Report$vtype	_jc_polyglot_main_Report$vtype;

// Class fields structure
struct _jc_polyglot_main_Report$fields_struct {
	struct _jc_java_lang_String$object	*cfg;
	struct _jc_java_lang_String$object	*context;
	struct _jc_java_lang_String$object	*debug;
	struct _jc_java_lang_String$object	*errors;
	struct _jc_java_lang_String$object	*frontend;
	struct _jc_java_lang_String$object	*imports;
	struct _jc_java_lang_String$object	*loader;
	struct _jc_object	*reportTopics;
	struct _jc_java_lang_String$object	*resolver;
	struct _jc_java_lang_String$object	*serialize;
	struct _jc_java_util_Stack$object	*should__5freport;
	struct _jc_java_lang_String$object	*time;
	struct _jc_object	*topics;
	struct _jc_java_lang_String$object	*types;
	struct _jc_java_lang_String$object	*verbose;
	struct _jc_java_lang_String$object	*visit;
	jboolean	noReporting;
};
extern _jc_polyglot_main_Report$fields_struct _jc_polyglot_main_Report$class_fields;

// Constructors
extern void _jc_polyglot_main_Report$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_main_Report$object *);

// Static methods
extern void _jc_polyglot_main_Report$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_polyglot_main_Report$method$addTopic$c2ee44fe5f835eed(_jc_env *, struct _jc_java_lang_String$object *, jint);
extern jint _jc_polyglot_main_Report$method$level$bc1cbf6db8b297c6(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_polyglot_main_Report$method$report$0373120f850dba20(_jc_env *, jint, struct _jc_java_lang_String$object *);
extern jboolean _jc_polyglot_main_Report$method$should__5freport$07fb826b9a33a534(_jc_env *, struct _jc_java_lang_String$object *, jint);
extern jboolean _jc_polyglot_main_Report$method$should__5freport$316269f2ec4db001(_jc_env *, struct _jc_object *, jint);
extern jboolean _jc_polyglot_main_Report$method$should__5freport$4eeed9984759a088(_jc_env *, struct _jc_object_array *, jint);

// Virtual methods structure
struct _jc_polyglot_main_Report$vmethods {
};

// Vtable
struct _jc_polyglot_main_Report$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_main_Report$vmethods	polyglot_main_Report;
};

// Vtype
struct _jc_polyglot_main_Report$vtype {
	_jc_type			type;
	_jc_polyglot_main_Report$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_Report$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_main_Report$refs {
    _jc_polyglot_main_Report$sub_refs	polyglot_main_Report;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_Report$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_Report$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_main_Report$sub_nonrefs	polyglot_main_Report;
};

// Object instance structure
struct _jc_polyglot_main_Report$object {
	_jc_polyglot_main_Report$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_Report$vtype	*vtype;
	_jc_polyglot_main_Report$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_Report$vtype _jc_polyglot_main_Report$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_Report, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_Report$class_object;

#endif	/* _JC_polyglot_main_Report_H_ */

==> jc-1.4.6.tar.gz: polyglot/main/Report.h <==
// public class polyglot.main.Report

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf9f146bdb7bc44d polyglot_main_Report

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_main_Report_H_
#define _JC_polyglot_main_Report_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Stack$object;

// Typedefs
typedef struct _jc_polyglot_main_Report$sub_refs	_jc_polyglot_main_Report$sub_refs;
typedef struct _jc_polyglot_main_Report$sub_nonrefs	_jc_polyglot_main_Report$sub_nonrefs;
typedef struct _jc_polyglot_main_Report$refs	_jc_polyglot_main_Report$refs;
typedef struct _jc_polyglot_main_Report$nonrefs	_jc_polyglot_main_Report$nonrefs;
typedef struct _jc_polyglot_main_Report$object	_jc_polyglot_main_Report$object;

typedef struct _jc_polyglot_main_Report$fields_struct	_jc_polyglot_main_Report$fields_struct;
typedef const struct _jc_polyglot_main_Report$vmethods	_jc_polyglot_main_Report$vmethods;
typedef const struct _jc_polyglot_main_Report$vtable	_jc_polyglot_main_Report$vtable;
typedef const struct _jc_polyglot_main_Report$vtype	_jc_polyglot_main_Report$vtype;

// Class fields structure
struct _jc_polyglot_main_Report$fields_struct {
	struct _jc_java_lang_String$object	*cfg;
	struct _jc_java_lang_String$object	*context;
	struct _jc_java_lang_String$object	*debug;
	struct _jc_java_lang_String$object	*errors;
	struct _jc_java_lang_String$object	*frontend;
	struct _jc_java_lang_String$object	*imports;
	struct _jc_java_lang_String$object	*loader;
	struct _jc_object	*reportTopics;
	struct _jc_java_lang_String$object	*resolver;
	struct _jc_java_lang_String$object	*serialize;
	struct _jc_java_util_Stack$object	*should__5freport;
	struct _jc_java_lang_String$object	*time;
	struct _jc_object	*topics;
	struct _jc_java_lang_String$object	*types;
	struct _jc_java_lang_String$object	*verbose;
	struct _jc_java_lang_String$object	*visit;
	jboolean	noReporting;
};
extern _jc_polyglot_main_Report$fields_struct _jc_polyglot_main_Report$class_fields;

// Constructors
extern void _jc_polyglot_main_Report$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_main_Report$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_polyglot_main_Report$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Report$method$addTopic$c2ee44fe5f835eed(_jc_env *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_polyglot_main_Report$method$level$bc1cbf6db8b297c6(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Report$method$report$0373120f850dba20(_jc_env *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_main_Report$method$should__5freport$07fb826b9a33a534(_jc_env *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_main_Report$method$should__5freport$316269f2ec4db001(_jc_env *, struct _jc_object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_main_Report$method$should__5freport$4eeed9984759a088(_jc_env *, struct _jc_object_array *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_main_Report$vmethods {
};

// Vtable
struct _jc_polyglot_main_Report$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_main_Report$vmethods	polyglot_main_Report;
};

// Vtype
struct _jc_polyglot_main_Report$vtype {
	_jc_type			type;
	_jc_polyglot_main_Report$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_Report$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_main_Report$refs {
    _jc_polyglot_main_Report$sub_refs	polyglot_main_Report;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_Report$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_Report$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_main_Report$sub_nonrefs	polyglot_main_Report;
};

// Object instance structure
struct _jc_polyglot_main_Report$object {
	_jc_polyglot_main_Report$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_Report$vtype	*vtype;
	_jc_polyglot_main_Report$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_Report$vtype _jc_polyglot_main_Report$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_Report, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_Report$class_object;

#endif	/* _JC_polyglot_main_Report_H_ */
